@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0507';
+our $VERSION = '0.0508';
 
 use Moo;
 use strictures 2;
@@ -173,7 +173,7 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0507
+version 0.0508
 
 =head1 SYNOPSIS
 
@@ -225,7 +225,7 @@ Regular expression to be used to parse-out unwanted punctuation.  Giving the
 constructor a value of C<''> or C<0> will override this and not exclude any
 characters from the results.
 
-Default: qr/(?!')[[:punct:]]/
+Default: C<qr/(?!')[[:punct:]]/>
 
 Note that the default does not exclude the single quote.
 
